summaryrefslogtreecommitdiffstats
path: root/media/formats/webm/webm_audio_client.h
diff options
context:
space:
mode:
Diffstat (limited to 'media/formats/webm/webm_audio_client.h')
-rw-r--r--media/formats/webm/webm_audio_client.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/media/formats/webm/webm_audio_client.h b/media/formats/webm/webm_audio_client.h
index fefa55f..06d7e0c 100644
--- a/media/formats/webm/webm_audio_client.h
+++ b/media/formats/webm/webm_audio_client.h
@@ -16,6 +16,7 @@
namespace media {
class AudioDecoderConfig;
+class EncryptionScheme;
// Helper class used to parse an Audio element inside a TrackEntry element.
class WebMAudioClient : public WebMParserClient {
@@ -27,8 +28,8 @@ class WebMAudioClient : public WebMParserClient {
void Reset();
// Initialize |config| with the data in |codec_id|, |codec_private|,
// |is_encrypted| and the fields parsed from the last audio track element this
// object was used to parse.
// Returns true if |config| was successfully initialized.
// Returns false if there was unexpected values in the provided parameters or
// audio track element fields.
@@ -36,7 +37,7 @@ class WebMAudioClient : public WebMParserClient {
const std::vector<uint8_t>& codec_private,
const int64_t seek_preroll,
const int64_t codec_delay,
- bool is_encrypted,
+ const EncryptionScheme& encryption_scheme,
AudioDecoderConfig* config);
private:
@@ -27,8 +28,8 @@ class WebMAudioClient : public WebMParserClient {
void Reset();
// Initialize |config| with the data in |codec_id|, |codec_private|,
- // |is_encrypted| and the fields parsed from the last audio track element this
- // object was used to parse.
+ // |encryption_scheme| and the fields parsed from the last audio track element
+ // this object was used to parse.
// Returns true if |config| was successfully initialized.
// Returns false if there was unexpected values in the provided parameters or